// app.dart
import 'package:flutter/material.dart';
import 'screens/home.dart';
import 'package:flutter/services.dart';
import 'dart:async';
import 'dart:developer';

import 'package:uni_links/uni_links.dart';
import 'package:splashscreen/splashscreen.dart';

class App extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        title: 'Vereign',
        theme: ThemeData(
            primaryColor: Color(0xFFd51d32),
            fontFamily: "Arial",
            textTheme: TextTheme(
                button: TextStyle(color: Colors.white, fontSize: 18.0),
                title: TextStyle(color: Colors.red))),
        home: new SplashScreen(
            seconds: 3,
            title: new Text(''),
            navigateAfterSeconds: new MainApp(),
            image: new Image.asset('assets/images/vereign_logo_text.png'),
            backgroundColor: Color(0xFFd51d32),
            photoSize: 100.0,
            loaderColor: Colors.white,
            loadingText: new Text('Loading', style: new TextStyle(
                color: Colors.white
            )),
        )
    );


  }
}

class MainApp extends StatefulWidget {
  @override
  _MainAppState createState() => _MainAppState();
}

class _MainAppState extends State<MainApp> {
  StreamSubscription _sub;

  String _appMode = "";

  // Url of the app which invoked OAuth
  String _invokerURL;
  String _host;

  @override
  initState() {
    super.initState();
    initUniLinks();
//    FlutterWebBrowser.openWebPage(url: 'https://demo1.vereign.com', androidToolbarColor: Color(0xFFd51d32));
  }

  @override
  dispose() {
    if (_sub != null) _sub.cancel();
    super.dispose();
  }

  Future<Null> initUniLinks() async {
    Uri initialUri;

    try {
      initialUri = await getInitialUri();
    } on PlatformException {
      initialUri = null;
    } on FormatException {
      initialUri = null;
    }
    updateAppMode(initialUri);

    _sub = getUriLinksStream().listen((Uri uri) {
      updateAppMode(uri);
    }, onError: (err) {
      log('got err: $err');
    });
  }

  updateAppMode(Uri uri) {
    if (uri?.path == "/authorize") {
      setState(() {
        _appMode = "oauth";
        _invokerURL = uri.queryParameters["invokerUrl"];
        _host = uri.queryParameters["host"];
      });
    } else {
      setState(() {
        _appMode = "app";
      });
    }
  }

  setMode(String mode) {
    setState(() {
      _appMode = mode;
    });
  }

  @override
  Widget build(BuildContext context) {
    return new Scaffold(
      appBar: new AppBar(title: Text("Vereign")),
      body: Home(
        mode: _appMode,
        invokerURL: _invokerURL,
        setMode: setMode,
        host: _host
      )
    );
  }
}